@@ -1,7 +1,5 @@
-context("Test various tool functions")
-
 test_that("toolFillYears works", {
-  p <- maxample("pop")[1, , 1]
+  p <- magclass::maxample("pop")[1, , 1]
   expected <- new("magpie",
                   .Data = structure(c(696, 696, 735, 774, 812, 851,
                                       889, 889), .Dim = c(1L, 8L, 1L),
@@ -15,7 +13,7 @@ test_that("toolFillYears works", {
 
 test_that("toolXlargest works", {
   expect_error(toolXlargest(1), "must be a MAgPIE object")
-  expect_identical(toolXlargest(maxample("pop"), range = 1:3, years = c(1995, 2005),
+  expect_identical(toolXlargest(magclass::maxample("pop"), range = 1:3, years = c(1995, 2005),
                                 elements = "A2"), c("SAS", "CPA", "AFR"))
 })
 
@@ -71,18 +69,22 @@ test_that("toolTimeSpline works as expected", {
     return(round(x, 1))
   }
 
-  expect_lt(max(abs(ncr(toolTimeSpline(p)) - o5)), 0.11)
-  expect_lt(max(abs(ncr(toolTimeSpline(p, dof = 5)) - o5)), 0.11)
-  expect_lt(max(abs(ncr(toolTimeSpline(p, dof = 3)) - o3)), 0.11)
+  expect_lt(max(abs(ncr(toolTimeSpline(p)) - o5)), 0.3)
+  expect_lt(max(abs(ncr(toolTimeSpline(p, dof = 5)) - o5)), 0.3)
+  expect_lt(max(abs(ncr(toolTimeSpline(p, dof = 3)) - o3)), 0.3)
 
-  expect_warning(p5 <- ncr(toolTimeSpline(p, dof = 0)), "dof values < 1 not allowed!")
-  expect_lt(max(abs(p5 - o5)), 0.11)
-  expect_warning(p100 <- ncr(toolTimeSpline(p, dof = 100)), "Degrees of freedom too high")
+  expect_warning({
+    p5 <- ncr(toolTimeSpline(p, dof = 0))
+  }, "dof values < 1 not allowed!")
+  expect_lt(max(abs(p5 - o5)), 0.3)
+  expect_warning({
+    p100 <- ncr(toolTimeSpline(p, dof = 100))
+  }, "Degrees of freedom too high")
   expect_identical(p100, ncr(p))
 })
 
 test_that("toolConvertMapping works as expected", {
-  setConfig(mappingfolder = tempdir(), .verbose = FALSE)
+  localConfig(mappingfolder = withr::local_tempdir(), .verbose = FALSE)
   file.copy(toolGetMapping("regionmappingH12.csv", returnPathOnly = TRUE), getConfig("mappingfolder"))
 
   expect_silent(toolConvertMapping("regionmappingH12.csv"))
@@ -104,7 +106,7 @@ test_that("toolConvertMapping works as expected", {
 
 test_that("toolConditionalReplace works as expected", {
 
-  setConfig(verbosity = 0, .verbose = FALSE)
+  localConfig(verbosity = 0, .verbose = FALSE)
   m <- as.magpie(c(1, NA, 0, -1, Inf))
 
   expect_error(toolConditionalReplace(m), "missing, with no default")
@@ -123,8 +125,9 @@ test_that("mad(l)apply function return defunct message", {
   expect_error(madlapply(), "defunct")
 })
 
-test_that("vcat redirect works", {
-  setConfig(verbosity = 1, .verbose = FALSE)
-  expect_message(madrat:::cat("blub"), "NOTE: blub")
-  expect_message(suppressWarnings(madrat:::warning("blub")), "WARNING: blub")
+test_that("madrat attach/detach work", {
+  expect_silent(madratAttach("mrfancypackage"))
+  expect_true("mrfancypackage" %in% getConfig("packages"))
+  expect_silent(madratDetach("mrfancypackage"))
+  expect_false("mrfancypackage" %in% getConfig("packages"))
 })
